<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>__pkg__</title>
</head>

<body>

    <div class='flex-center page-container' pragma #display-wrapper>
        <h1> Hello, __pkg__ </h1>
        <p> Yes this works </p>

        <div pragma #display></div>
    </div>

    <div loader data-transition=.3 style="position: absolute;
        width: 100vw;
        height: 100vh;
        top: 0; left: 0; 
        z-index: 99999999999;
        background: #161616;
    "></div>

    <script src="docs/scripts/__pkg__.umd.js?r={{ random }}"></script>
    <script src="docs/__pkg___demo.js?r={{ random }}"></script>
</body>

</html>